pub struct ProcMeshRef { /* private fields */ }Expand description
A reference to a ProcMesh, consisting of a set of ranked ProcRefs,
arranged into a region. ProcMeshes are named, uniquely identifying the
ProcMesh from which the reference was derived.
ProcMeshes can be sliced to create new ProcMeshes with a subset of the original ranks.
Implementations
Sourceimpl ProcMeshRef
impl ProcMeshRef
Sourcepub fn new_singleton(id: ProcMeshId, proc_ref: ProcRef) -> Self
pub fn new_singleton(id: ProcMeshId, proc_ref: ProcRef) -> Self
Create a singleton ProcMeshRef, given the provided ProcRef and id.
This is used to support creating local singleton proc meshes to support this_proc()
in python client actors.
pub fn id(&self) -> &ProcMeshId
pub fn host_mesh_id(&self) -> Option<&HostMeshId>
Sourcepub fn hosts(&self) -> Option<&HostMeshRef>
pub fn hosts(&self) -> Option<&HostMeshRef>
Returns the HostMeshRef that owns this ProcMeshRef, if any.
Sourcepub async fn actor_states(
&self,
cx: &impl Actor,
id: ActorMeshId,
) -> Result<ValueMesh<State<ActorState>>>
pub async fn actor_states( &self, cx: &impl Actor, id: ActorMeshId, ) -> Result<ValueMesh<State<ActorState>>>
Query the state of all actors in this mesh matching the given id.
pub async fn proc_states( &self, cx: &impl Actor, keepalive: Option<SystemTime>, ) -> Result<Option<ValueMesh<State<ProcState>>>>
Sourcepub async fn spawn<A: RemoteSpawn, C: Actor>(
&self,
cx: &C,
name: &str,
params: &A::Params,
) -> Result<ActorMesh<A>>
pub async fn spawn<A: RemoteSpawn, C: Actor>( &self, cx: &C, name: &str, params: &A::Params, ) -> Result<ActorMesh<A>>
Spawn an actor on all of the procs in this mesh, returning a new ActorMesh.
Bounds:
A: Actor- the actor actually runs inside each proc.A: Referable- so we can return typedActorRef<A>s inside theActorMesh.A::Params: RemoteMessage- spawn parameters must be serializable and routable.
Sourcepub async fn spawn_service<A: RemoteSpawn, C: Actor>(
&self,
cx: &C,
name: &str,
params: &A::Params,
) -> Result<ActorMesh<A>>
pub async fn spawn_service<A: RemoteSpawn, C: Actor>( &self, cx: &C, name: &str, params: &A::Params, ) -> Result<ActorMesh<A>>
Spawn a ‘service’ actor. Service actors are singletons, using reserved names. The provided name is used verbatim as the actor’s name, and thus it may be persistently looked up by constructing the appropriate name.
Note: avoid using service actors if possible; the mechanism will be replaced by an actor registry.
Sourcepub async fn spawn_with_name<A: RemoteSpawn, C: Actor>(
&self,
cx: &C,
name: ActorMeshId,
params: &A::Params,
supervision_display_name: Option<String>,
is_system_actor: bool,
) -> Result<ActorMesh<A>>
pub async fn spawn_with_name<A: RemoteSpawn, C: Actor>( &self, cx: &C, name: ActorMeshId, params: &A::Params, supervision_display_name: Option<String>, is_system_actor: bool, ) -> Result<ActorMesh<A>>
Spawn an actor on all procs in this mesh under the given
ActorMeshId, returning a new ActorMesh.
This is the underlying implementation used by [spawn]; it
differs only in that the actor mesh id is passed explicitly
rather than as a &str.
Bounds:
A: Actor- the actor actually runs inside each proc.A: Referable- so we can return typedActorRef<A>s inside theActorMesh.A::Params: RemoteMessage- spawn parameters must be serializable and routable.C::A: Handler<MeshFailure>- in order to spawn actors, the actor must accept messages of typeMeshFailure. This is delivered when the actors spawned in the mesh have a failure that isn’t handled.